"""empty message

Revision ID: 895c6b11c356
Revises: 3cbf4759a67e
Create Date: 2024-05-15 16:58:29.359351

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = '895c6b11c356'
down_revision = '3cbf4759a67e'
branch_labels = None
depends_on = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column('user_infos', sa.Column('first_downloaded_at', sa.TIMESTAMP(timezone=True), nullable=True), schema='fansly')
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('user_infos', 'first_downloaded_at', schema='fansly')
    # ### end Alembic commands ###
