"""empty message

Revision ID: 160553c5979e
Revises: 895c6b11c356
Create Date: 2024-07-03 11:48:34.442237

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = '160553c5979e'
down_revision = '895c6b11c356'
branch_labels = None
depends_on = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_index('ix_content_media_mass_message_id', 'content_media_asso', ['mass_message_id'], unique=False, schema='fansly')
    op.create_index('ix_content_media_media_id', 'content_media_asso', ['media_id'], unique=False, schema='fansly')
    op.create_index('ix_content_media_message_id', 'content_media_asso', ['message_id'], unique=False, schema='fansly')
    op.create_index('ix_content_media_post_id', 'content_media_asso', ['post_id'], unique=False, schema='fansly')
    op.create_index('ix_content_media_story_id', 'content_media_asso', ['story_id'], unique=False, schema='fansly')
    op.create_index('ix_content_media_mass_message_id', 'content_media_asso', ['mass_message_id'], unique=False, schema='onlyfans')
    op.create_index('ix_content_media_media_id', 'content_media_asso', ['media_id'], unique=False, schema='onlyfans')
    op.create_index('ix_content_media_message_id', 'content_media_asso', ['message_id'], unique=False, schema='onlyfans')
    op.create_index('ix_content_media_post_id', 'content_media_asso', ['post_id'], unique=False, schema='onlyfans')
    op.create_index('ix_content_media_story_id', 'content_media_asso', ['story_id'], unique=False, schema='onlyfans')
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_index('ix_content_media_story_id', table_name='content_media_asso', schema='onlyfans')
    op.drop_index('ix_content_media_post_id', table_name='content_media_asso', schema='onlyfans')
    op.drop_index('ix_content_media_message_id', table_name='content_media_asso', schema='onlyfans')
    op.drop_index('ix_content_media_media_id', table_name='content_media_asso', schema='onlyfans')
    op.drop_index('ix_content_media_mass_message_id', table_name='content_media_asso', schema='onlyfans')
    op.drop_index('ix_content_media_story_id', table_name='content_media_asso', schema='fansly')
    op.drop_index('ix_content_media_post_id', table_name='content_media_asso', schema='fansly')
    op.drop_index('ix_content_media_message_id', table_name='content_media_asso', schema='fansly')
    op.drop_index('ix_content_media_media_id', table_name='content_media_asso', schema='fansly')
    op.drop_index('ix_content_media_mass_message_id', table_name='content_media_asso', schema='fansly')
    # ### end Alembic commands ###
